;*******************(ASM) COPYRIGHT 2021 Masses-Chip ****************************
;* Project Name		  : M9F680_ADC.Prj
;* File Name		  : M9F680_ADC.ASM
;* Author			  : MASSES CHIP
;* Version			  : V2.00
;* Date				  : 2021/09/15
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例AD采集通道为AIN8(IOB0),时钟源选择为Fcpu/16T，内部参考2V
;采集10次AD值，去掉最大值和最小值，对剩下的AD值求平均,结果存放在ADC_DATA_SUM_H、
;ADC_DATA_SUM_L中，作为一次AD值
;//******************************************************************************
;//===============================================================================
;//***********************************头文件**************************************
;//用户不可更改
;//===============================================================================
		LIST		p=M9F680
INCLUDE		M9F680.INC

;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
userdata udata	H'00'
ADC_MAX_DATAH		RES		1	
ADC_MAX_DATAL		RES		1
ADC_MIN_DATAH		RES		1
ADC_MIN_DATAL		RES		1
ADC_DATA_SUM_L		RES		1
ADC_DATA_SUM_H		RES		1
R_Count				RES		1

;//===============================================================================
;//*********************************C O D E***************************************
;//===============================================================================	
		ORG			0000H
		GOTO		MainProgram
		ORG			0008H
		GOTO		Interrupt	

;//===============================================================================
;//********************************程序主函数*************************************
;//===============================================================================			
;//------------------------------程序初始化---------------------------------------
MainProgram:
		CALL       	SYSTEM_INIT				;//系统初始化
		CALL       	Clr_RAM_0000H_01FFH		;//清零RAM
		CALL       	ADC_INIT				;//ADC初始化
;//------------------------------主函数循环---------------------------------------		
MainLoop:
		CLRWDT	
		call		ADC_Work
		GOTO		MainLoop
		
		
;//===============================================================================
;//******************************中断服务子程序***********************************
;//中断处理函数
;//===============================================================================
;//中断进来	
Interrupt:
		;//
		;//中断处理程序
		;//
Interrupt_END:	
;//中断结束
	    RETIE		1						;//返回A、BSR、STATUS的值

;//===============================================================================
;//*********************************ADC初始化*************************************
;//ADC设置：选择通道为AIN8，数据格式为高位在前，
;//时钟源选择为Fcpu/16T，内部参考2V
;//===============================================================================	
ADC_INIT:
;//1、IO设置
		MOVIA		0x01
		MOVAR		ANSB
		MOVIA		0xFE
		MOVAR		OEB
		
;//2、ADC设置
		MOVIA		0xA8
		MOVAR		ADCON0
		MOVIA		0x05
		MOVAR		ADCON1
		MOVIA		0x00
		MOVAR		ADCON2	
		CLRR		ADCON3
		RETURN
		
		

;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置个IO状态为输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================		
SYSTEM_INIT:
;//-----------------------------------------------------------------------           
;//Init Clock		
		MOVIA       b'00000000'
		MOVAR		OSCM
;//Init IO 
		BANKBSR	   	0x0F		;//切页，ANSX寄存器需要切页操作
        ;//IOA
        MOVIA      	0x00 
		MOVAR		ANSA		;//0:数字口	  1:模拟口 
        MOVAR     	PUA			;//0:上拉关闭 1:上拉使能  	 	
        MOVAR      	PDA			;//0:下拉关闭 1:下拉使能
		MOVAR      	IOA        	;//0:输出低   1:输出高
		MOVIA      	0xFF    	
        MOVAR      	OEA			;//0:输入     1:输出   	
		;//IOB
        MOVIA      	0x00
		MOVAR		ANSB		    	
        MOVAR      	PUB 	
        MOVAR      	PDB  	
        MOVAR      	IOB
		MOVIA      	0xFF    	
        MOVAR      	OEB
		;//IOC
        MOVIA      	0x00
		MOVAR		ANSC
        MOVAR      	PUC  	
        MOVAR      	PDC   	
        MOVAR      	IOC
		MOVIA      	0xFF    	
        MOVAR      	OEC		
		;//IOD
        MOVIA      	0x00 
		MOVAR		ANSD
        MOVAR      	PUD    	
        MOVAR      	PDD   	
        MOVAR      	IOD 
		MOVIA      	0xFF    	
        MOVAR      	OED			  
;//------------------------------------------------------------------------      
;//Init Interrupt          
        BCLR       	OPTION,6  		;//1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
		BCLR       	OPTION,7		;//1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
		RETURN
		
;//===============================================================================
;//*****************************RAM清零(0000H~01FFH)******************************
;//RAM清零：RAM区0000H~01FFH全部清零；
;//===============================================================================				
Clr_RAM_0000H_01FFH:		
		CLRR    	FSR1L    
		CLRR    	FSR1H
ClrRam_Loop:
		MOVIA		0x00
		MOVAR   	INDF1
		INCR    	FSR1L,1
		MOVIA		0
		ADCAR		FSR1H,1
		MOVIA		2
		SUBRA		FSR1H,0
		JBTS1		STATUS,C
		GOTO    	ClrRam_Loop
RAM_INIT_END:
		RETURN				
		

#INCLUDE		ADC_Work.INC

		END
;//******************************END OF FILE*************************************
        











