;*******************(ASM) COPYRIGHT 2021 Masses-Chip ****************************
;* Project Name		  : M9F680_I2C_MASTER.prj
;* File Name		  : M9F680_I2C_MASTER.ASM
;* Author			  : MASSES CHIP
;* Version			  : V2.00
;* Date				  : 2021/10/08
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例是作为I2C主机(SCL:IOB0 SDA:IOB1)
;主机写：主机向从机发送17个数据，第一个数据为要写入RAM区的地址，其他数据为写入的数据
;主机读：主机先发送要读出RAM区的地址，再读16个数据依次放在RAM(0x0010-0x001F)中
;//******************************************************************************
;//===============================================================================
;//***********************************头文件**************************************
;//用户不可更改
;//===============================================================================
		LIST 		P=M9F680
INCLUDE	 	M9F680.INC

;+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
#define      STA_M_START    	0X08    ;主机发送开始信号完成
#define      STA_M_RSTART    	0X10    ;主机发送重新开始信号完成
#define      STA_M_W_ADRACK  	0X18   	;主机发送地址应答
#define      STA_M_W_ADRNACK 	0X20   	;主机发送地址不应答
#define      STA_M_W_DATACK   	0X28    ;主机发送数据应答
#define      STA_M_W_DATNACK  	0X30    ;主机发送数据不应答
#define		 STA_M_W_ADRACK_LOST 0x38	;主机仲裁失败
#define      STA_M_R_ADRACK   	0X40    ;主机接收地址应答
#define      STA_M_R_ADRNACK  	0X48    ;主机接收地址不应答
#define      STA_M_R_DATACK   	0X50    ;主机接收数据应答
#define      STA_M_R_DATNACK  	0X58    ;主机接收数据不应答
#define		 STA_M_W_ERR		0x00	;总线错误
;+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
userdata			udata	H'00'
I2C_DATA 			res 	1
Number 				res 	1


;//===============================================================================
;//*********************************C O D E***************************************
;//===============================================================================	
		ORG			0000H
		GOTO		MainProgram
		ORG			0008H
		GOTO		Interrupt	

;//===============================================================================
;//********************************程序主函数*************************************
;//===============================================================================			
;//------------------------------程序初始化---------------------------------------
MainProgram:
		CALL       	SYSTEM_INIT				;//系统初始化
		CALL       	Clr_RAM_0000H_01FFH		;//清零RAM
		CALL       	I2C_INIT				;//I2C初始化
;//------------------------------主函数循环---------------------------------------		
MainLoop:
		CLRWDT
		CALL		I2C_Master_Write		;//I2C主机写
		CALL		I2C_Master_Read			;//I2C主机读
		GOTO		MainLoop

;//===============================================================================
;//******************************中断服务子程序***********************************
;//===============================================================================
;//中断进来	
Interrupt:
		sPUSH
		BCLR    	I2CCR,3
		BCLR		INTCR0,5
Interrupt_END:	
;//中断结束
		sPOP
	    RETIE		1						;//返回A、BSR、STATUS的值

		
;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置个IO状态为输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================		
SYSTEM_INIT:
;//-----------------------------------------------------------------------           
;//Init Clock		
        MOVIA       b'00000000'
		MOVAR       OSCM
		
;//Init IO 
        ;//IOA
        MOVIA      	0x00 
		MOVAR		ANSA		;//0:数字口	  1:模拟口 
        MOVAR     	PUA			;//0:上拉关闭 1:上拉使能  	 	
        MOVAR      	PDA			;//0:下拉关闭 1:下拉使能
		MOVAR      	IOA        	;//0:输出低   1:输出高
		MOVIA      	0xFF    	
        MOVAR      	OEA			;//0:输入     1:输出   	
		;//IOB
        MOVIA      	0x00
		MOVAR		ANSB		    	
        MOVAR      	PUB 	
        MOVAR      	PDB  	
        MOVAR      	IOB
		MOVIA      	0xFF    	
        MOVAR      	OEB
		;//IOC
        MOVIA      	0x00
		MOVAR		ANSC
        MOVAR      	PUC  	
        MOVAR      	PDC   	
        MOVAR      	IOC
		MOVIA      	0xFF    	
        MOVAR      	OEC		
		;//IOD
        MOVIA      	0x00 
		MOVAR		ANSD
        MOVAR      	PUD    	
        MOVAR      	PDD   	
        MOVAR      	IOD 
		MOVIA      	0xFF    	
        MOVAR      	OED
		  
;//------------------------------------------------------------------------      
;//Init Interrupt           
        BCLR       	OPTION,GIEH  		;//1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
		BCLR       	OPTION,GIEL			;//1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
		RETURN

;//===============================================================================
;//*****************************RAM清零(0000H~01FFH)******************************
;//RAM清零：RAM区0000H~01FFH全部清零；
;//===============================================================================				
Clr_RAM_0000H_01FFH:		
		CLRR    	FSR1L    
		CLRR    	FSR1H
ClrRam_Loop:
		MOVIA		0x00
		MOVAR   	INDF1
		INCR    	FSR1L,1
		MOVIA		0
		ADCAR		FSR1H,1
		MOVIA		2
		SUBRA		FSR1H,0
		JBTS1		STATUS,C
		GOTO    	ClrRam_Loop
RAM_INIT_END:
		RETURN			
		
;================================I2C主机读写====================================
;***************************************************************************
#INCLUDE				M9F680_I2C_MASTER_WR.INC

		END
		
;//******************************END OF FILE*************************************
