;*******************(ASM) COPYRIGHT 2021 Masses-Chip ****************************
;* Project Name		  : M9F680_I2C_MASTER.prj
;* File Name		  : M9F680_I2C_MASTER_WR.INC
;* Author			  : MASSES CHIP
;* Version			  : V2.00
;* Date				  : 2021/10/08
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例是作为I2C主机(SCL:IOB0 SDA:IOB1)
;主机写：主机向从机发送17个数据，第一个数据为要写入RAM区的地址，其他数据为写入的数据
;主机读：主机先发送要读出RAM区的地址，再读16个数据依次放在RAM(0x010)中
;//******************************************************************************


;//===============================================================================
;//**********************************I2C初始化***********************************
;1、端口设置：设置IOB0、IOB1为上拉、数字口，设置端口复用功能IOB0---SCL,IOB1---SDA
;2、I2C设置：作主机
;3、开启总中断
;//===============================================================================	
I2C_INIT:
;//1、端口设置
		BSET		PUB,0
		BSET		PUB,1
		CLRR		ANSB
		BANKBSR     0x0F
		MOVIA       0x10
		MOVAR       MPSCL			;//SCL---IOB0
		MOVIA       0x11
		MOVAR       MPSDA			;//SDA---IOB1
		
;//2、I2C设置		
		MOVIA		0x40
		MOVAR		I2CCR
		
;//3、开中断
		BSET      OPTION,GIEH 
		RETURN
		
;//===============================================================================
;//*********************************I2C主机写*************************************
;//主机写：主机向从机发送17个数据，第一个数据为要写入RAM区的地址，其他数据为写入的数据
;//===============================================================================			
I2C_Master_Write:
		CLRR		I2C_DATA
		CAll		I2C_Start			;//起始指令
		MOVIA		0xA0
		CALL		Send_Add
		MOVIA		0x10
		CALL		Send_Data
I2C_Master_Write_Loop:
		MOVR		I2C_DATA,0
		MOVAR		I2CDATA
		CALL		Send_Data
		INCR		I2C_DATA,1
		MOVIA		0x10
		JERA		I2C_DATA	
		GOTO		I2C_Master_Write_Loop
		CALL		I2C_STOP			;//结束指令
		RETURN		


;//===============================================================================
;//*********************************I2C主机读*************************************
;主机读：主机先发送要读出RAM区的地址，再读16个数据依次放在RAM(0x010)中
;//===============================================================================	
I2C_Master_Read:
		CLRR		FSR1H
		MOVIA		0x10
		MOVAR		FSR1L				;//存放地址
		MOVIA		0x10				;//读16位数据
		MOVAR		Number
		CAll		I2C_Start			;//起始指令
		MOVIA		0xA0
		CALL		Send_Add			;//发送从机地址写
		MOVIA		0x20
		CALL		Send_Data			;//发送要读出的RAM区地址
		CALL		I2C_Rstart			;//重复起始指令
		MOVIA		0xA1
		CALL		Send_Add			;//发送从机地址读
		DECR		Number,1
I2C_Master_Read_Loop:
		CALL		Receive_Data
		DJZR		Number,1
		GOTO		I2C_Master_Read_Loop
		CALL		STOP_Receive
		CALL		I2C_STOP
		RETURN
		
;******************************************************************************
;=================================起始信号=====================================
;******************************************************************************	
I2C_Start:
		BSET    	I2CCR,5   			;开始信号
I2C_Start_Wait:	
		JBTS1		I2CCR,3				;//等待起始信号发送完成
		GOTO		I2C_Start_Wait
		MOVIA		STA_M_START			;//判断状态
		JERA		I2CSTA
		GOTO		STATE_Err
		BCLR    	I2CCR,5   			;清开始信号
		RETURN		

;******************************************************************************
;=================================重复起始信号=================================
;******************************************************************************	
I2C_Rstart:
		BSET    	I2CCR,5   			;开始信号
		BSET		INTCR0,5
I2C_Rstart_Wait1:
		JBTS0		I2CCR,3
		GOTO		I2C_Rstart_Wait1
I2C_Rstart_Wait2:
		JBTS1		I2CCR,3
		GOTO		I2C_Rstart_Wait2
		MOVIA		STA_M_RSTART
		JERA		I2CSTA
		GOTO		STATE_Err
		BCLR    	I2CCR,5   			;清开始信号
		RETURN
		
;******************************************************************************
;============================发送从机地址写====================================
;******************************************************************************			
Send_Add:
		MOVAR		I2CDATA
		BSET		INTCR0,5			;//开中断
Send_Add_Wait1:
		JBTS0		I2CCR,3				;//等待数据发送完成清除中断
		GOTO		Send_Add_Wait1
Send_Add_Wait2:
		JBTS1		I2CCR,3
		GOTO		Send_Add_Wait2
		RRR			AREG,0
		JBTS0		STATUS,C			;//判断读写
		GOTO		Send_Add_Read
		MOVIA		STA_M_W_ADRNACK
		JERA        I2CSTA				;//判断发送地址是否应答
		GOTO		Send_Add_ACK
		GOTO		STATE_W_ADRNACK		;//未应答
Send_Add_ACK:
		MOVIA		STA_M_W_ADRACK
		JERA		I2CSTA
		GOTO		STATE_Err
		RETURN		

;******************************************************************************
;============================发送从机地址读====================================
;******************************************************************************			
Send_Add_Read:
		BSET    	I2CCR,2				;//应答位置1
		MOVIA		STA_M_R_ADRNACK		;//判断读地址是否应答
		JERA		I2CSTA
		GOTO		Send_Add_Read_ACK
		GOTO		STATE_W_ADRNACK		;//未应答
Send_Add_Read_ACK:
		MOVIA		STA_M_R_ADRACK
		JERA		I2CSTA
		GOTO		STATE_Err
		RETURN

;******************************************************************************
;===============================发送数据=======================================
;******************************************************************************			
Send_Data:
		MOVAR		I2CDATA
		BSET		INTCR0,5
Send_Data_Wait1:
		JBTS0		I2CCR,3				;//等待数据发送完毕
		GOTO		Send_Data_Wait1
Send_Data_Wait2:
		JBTS1		I2CCR,3				;//等待开始信号发送完成
		GOTO		Send_Data_Wait2	
		MOVIA		STA_M_W_DATNACK		;//判断发送数据是否应答
		JERA		I2CSTA
		GOTO		Send_Data_ACK
		GOTO		STATE_WDATNACK		;//未应答
Send_Data_ACK:
		MOVIA		STA_M_W_DATACK
		JERA		I2CSTA
		GOTO		STATE_Err
		RETURN

;******************************************************************************
;===============================接收数据=======================================
;******************************************************************************			
Receive_Data:
		BSET		INTCR0,5
Receive_Data_Wait1:
		JBTS0		I2CCR,3				;//等待数据接收完毕
		GOTO		Receive_Data_Wait1
Receive_Data_Wait2
		JBTS1		I2CCR,3				;//等待数据发送完毕
		GOTO		Receive_Data_Wait2
		MOVIA		STA_M_R_DATACK
		JERA		I2CSTA
		GOTO		STATE_Err
		MOVR		I2CDATA,0,0
		MOVAR		POSTINC1			;//读出数据写入RAM
		RETURN

;******************************************************************************
;=================================结束信号=====================================
;******************************************************************************	
I2C_STOP:
		BSET    	I2CCR,4   				;结束信号
		BSET		INTCR0,5
I2C_STOP_Wait:
		JBTS0		I2CCR,3
		GOTO		I2C_STOP_Wait
		RETURN

;******************************************************************************
;=================================停止接收=====================================
;******************************************************************************	
STOP_Receive:
		BCLR    	I2CCR,2							;//关闭应答
		BSET		INTCR0,5
STOP_Receive_Wait1:
		JBTS0		I2CCR,3
		GOTO		STOP_Receive_Wait1
STOP_Receive_Wait2:
		JBTS1		I2CCR,3
		GOTO		STOP_Receive_Wait2
		MOVIA		STA_M_R_DATNACK
		JERA		I2CSTA
		GOTO		STATE_Err
		MOVR      	I2CDATA,0,0
		MOVAR     	INDF1
		RETURN

;******************************************************************************
;=================================状态错误=====================================
;******************************************************************************	
STATE_Err:
		NOP
		GOTO		STATE_Err

;******************************************************************************
;===============================写地址未应答===================================
;******************************************************************************	
STATE_W_ADRNACK:
		NOP
		GOTO		STATE_W_ADRNACK

;******************************************************************************
;===============================写数据未应答===================================
;******************************************************************************	
STATE_WDATNACK:
		NOP
		GOTO		STATE_WDATNACK
