;*******************(ASM) COPYRIGHT 2021 Masses-Chip ****************************
;* Project Name		  : M9F680_I2C_SLAVER.prj
;* File Name		  : M9F680_I2C_SLAVER.ASM
;* Author			  : MASSES CHIP
;* Version			  : V2.00
;* Date				  : 2021/10/8
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例是作为I2C从机机(SCL:IOB0 SDA:IOB1)
;从机读：从机接收数据放入设定的RAM区中，从机接收的第一个数据为要写入RAM的地址
;其他数据依次写入RAM中
;从机写：主机会先发送一个数据当作要读出RAM区的地址，再依次把RAM区数据写给主机
;******************************************************************************
;===============================================================================
;***********************************头文件**************************************
;用户不可更改
;===============================================================================
		LIST 		P=M9F680
INCLUDE	 	M9F680.INC

;+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#define		STA_S_RSTART		0xA0		;//从机发送重复开始或停止信号
#define		STA_S_W_ADRACK		0xA8		;//从机发送地址应答
#define		STA_S_W_DATACK		0xB8		;//从机发送数据应答
#define		STA_S_W_DATNACK		0xC0		;//从机发送数据无应答
#define		STA_S_W_LAST		0xC8		;//从机发送最后数据应答
#define		STA_S_R_ADRACK		0x60		;//从机接收地址应答
#define		STA_S_R_DATACK		0x80		;//从机接收数据应答
#define		STA_S_R_ADRNACK		0x88		;//从机接收地址无应答
;+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
userdata			udata	H'00'
Number				res		1
I2C_Flag			res		1
RAM_Add				res		1

;//===============================================================================
;//*********************************C O D E***************************************
;//===============================================================================	
		ORG       	0000H
 		GOTO		MainProgram
		ORG		  	0008H
		GOTO      	Interrupt

;//===============================================================================
;//********************************程序主函数*************************************
;//===============================================================================			
;//------------------------------程序初始化---------------------------------------
MainProgram:
		CALL       	SYSTEM_INIT				;//系统初始化
		CALL       	Clr_RAM_0000H_01FFH		;//清零RAM
		CALL       	I2C_INIT				;//I2C初始化
;//------------------------------主函数循环---------------------------------------		
MainLoop:
		CLRWDT	
		GOTO		MainLoop

;//===============================================================================
;//******************************中断服务子程序***********************************
;//===============================================================================	
Interrupt:
		sPUSH
		JBTS0		I2CCR,3
		CALL		I2C_Slaver_Work
Interrupt_END:
;//中断结束
		BCLR		I2CCR,3
		sPOP
	    RETIE		1						;//返回A、BSR、STATUS的值

		
;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置个IO状态为输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================		
SYSTEM_INIT:
;//-----------------------------------------------------------------------           
;//Init Clock		
        MOVIA       b'00000000'
		MOVAR       OSCM 
		
;//Init IO 
        ;//IOA
        MOVIA      	0x00 
		MOVAR		ANSA		;//0:数字口	  1:模拟口 
        MOVAR     	PUA			;//0:上拉关闭 1:上拉使能  	 	
        MOVAR      	PDA			;//0:下拉关闭 1:下拉使能
		MOVAR      	IOA        	;//0:输出低   1:输出高
		MOVIA      	0xFF    	
        MOVAR      	OEA			;//0:输入     1:输出   	
		;//IOB
        MOVIA      	0x00
		MOVAR		ANSB		    	
        MOVAR      	PUB 	
        MOVAR      	PDB  	
        MOVAR      	IOB
		MOVIA      	0xFF    	
        MOVAR      	OEB
		;//IOC
        MOVIA      	0x00
		MOVAR		ANSC
        MOVAR      	PUC  	
        MOVAR      	PDC   	
        MOVAR      	IOC
		MOVIA      	0xFF    	
        MOVAR      	OEC		
		;//IOD
        MOVIA      	0x00 
		MOVAR		ANSD
        MOVAR      	PUD    	
        MOVAR      	PDD   	
        MOVAR      	IOD 
		MOVIA      	0xFF    	
        MOVAR      	OED
		
;//------------------------------------------------------------------------      
;//Init Interrupt           
        BCLR       	OPTION,GIEH  		;//1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
		BCLR       	OPTION,GIEL			;//1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
		RETURN
		
;//===============================================================================
;//*****************************RAM清零(0000H~01FFH)******************************
;//RAM清零：RAM区0000H~01FFH全部清零；
;//===============================================================================				
Clr_RAM_0000H_01FFH:		
		CLRR    	FSR1L    
		CLRR    	FSR1H
ClrRam_Loop:
		MOVIA		0x00
		MOVAR   	INDF1
		INCR    	FSR1L,1
		MOVIA		0
		ADCAR		FSR1H,1
		MOVIA		2
		SUBRA		FSR1H,0
		JBTS1		STATUS,C
		GOTO    	ClrRam_Loop
RAM_INIT_END:
		RETURN
		
;================================I2C从机工作====================================
;***************************************************************************
#INCLUDE				M9F680_I2C_SLAVER_WORK.INC

		END
		
;//******************************END OF FILE*************************************
