;*******************(ASM) COPYRIGHT 2021 Masses-Chip ****************************
;* Project Name		  : M9F680_I2C_SLAVER.prj
;* File Name		  : M9F680_I2C_SLAVER.ASM
;* Author			  : MASSES CHIP
;* Version			  : V2.00
;* Date				  : 2021/10/8
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例是作为I2C从机机(SCL:IOB0 SDA:IOB1)
;从机读：从机接收数据放入设定的RAM区中，从机接收的第一个数据为要写入RAM的地址
;其他数据依次写入RAM中
;从机写：主机会先发送一个数据当作要读出RAM区的地址，再依次把RAM区数据写给主机
;******************************************************************************

;//===============================================================================
;//**********************************I2C初始化***********************************
;1、端口设置：设置IOB0、IOB1为上拉、数字口，设置端口复用功能IOB0---SCL,IOB1---SDA
;2、I2C设置：作从机，从机地址0xA0
;3、开中断
;4、在RAM区写数据：在RAM区(0x0020-0x002F)写入0x0F-0x00
;//===============================================================================	
I2C_INIT:
;//1、端口设置
		BSET		PUB,0
		BSET		PUB,1
		CLRR		ANSB
		BANKBSR     0x0F
		MOVIA       0x10
		MOVAR       MPSCL				;//SCL---IOB0
		MOVIA       0x11
		MOVAR       MPSDA				;//SDA---IOB1

;//2、I2C设置
		MOVIA		0x44	
		MOVAR		I2CCR		
		MOVIA		0xA0			
		MOVAR		I2CADR

;//3、开中断
		BSET		INTCR0,5
        BSET		OPTION,GIEH 

;//4、在RAM区写数据
		CLRR		FSR0H
		MOVIA		0x20
		MOVAR		FSR0L
		MOVIA		0x0F
		MOVAR		Number
Write_RAM:								;//RAM区(0x0020-0x002F)写入0x0F-0x00
		MOVRR		Number,POSTINC0
		DJZR		Number,1
		GOTO		Write_RAM
		RETURN

;//===============================================================================
;//**********************************I2C从机中断处理******************************
;//从机读：从机接收数据放入设定的RAM区中，从机接收的第一个数据为要写入RAM的地址
;//其他数据依次写入RAM中
;//从机写：主机会先发送一个数据当作要读出RAM区的地址，再依次把RAM区数据写给主机
;//===============================================================================	
I2C_Slaver_Work:
		MOVIA		STA_S_R_ADRACK		;//从机接收地址应答
		XORAR		I2CSTA,0,0
		JBTS0		STATUS,Z 
        GOTO		STATE_SRADRACK
		MOVIA		STA_S_R_DATACK		;//从机接收数据应答
		XORAR		I2CSTA,0,0
		JBTS0		STATUS,Z
        GOTO		STATE_SRDATACK
		MOVIA		STA_S_R_ADRNACK		;//从机接收地址无应答
		XORAR		I2CSTA,0,0
		JBTS0		STATUS,Z
        GOTO		STATE_SRADRNACK
		MOVIA		STA_S_RSTART		;//从机发送重复开始或停止信号
		XORAR		I2CSTA,0,0
		JBTS0		STATUS,Z
        GOTO		STATE_SRSTART		
		MOVIA		STA_S_W_ADRACK		;//从机发送地址应答
		XORAR		I2CSTA,0,0
		JBTS0		STATUS,Z
        GOTO		STATE_SWADRACK
		MOVIA		STA_S_W_DATACK		;//从机发送数据应答
		XORAR		I2CSTA,0,0
		JBTS0		STATUS,Z
        GOTO		STATE_SWDATACK
		MOVIA		STA_S_W_DATNACK		;//从机发送数据无应答 
		XORAR		I2CSTA,0,0
		JBTS0		STATUS,Z
        GOTO		STATE_SWDATNACK
		MOVIA		STA_S_W_LAST		;//从机发送最后数据应答 
		XORAR		I2CSTA,0,0
		JBTS0		STATUS,Z
        GOTO		STATE_SWLAST
		GOTO      	STATE_Err

;******************************************************************************
;==============================从机接收地址应答================================
;******************************************************************************	
STATE_SRADRACK:  					
        BSET        I2CCR,2
		BSET      	I2C_Flag,0
		MOVIA     	0x20
		MOVAR     	Number
		RETURN

;******************************************************************************
;==============================从机接收数据应答================================
;******************************************************************************	
STATE_SRDATACK:
		JBTS0		I2C_Flag,0
		GOTO		Receive_RAM_Add
		CLRR		FSR1H
		MOVRR		RAM_Add,FSR1L
		MOVRR		I2CDATA,INDF1		;//数据放入RAM中
		INCR		RAM_Add,1
		BSET        I2CCR,2
		DJNZR		Number,1
		BCLR    	I2CCR,2
		RETURN
Receive_RAM_Add:						;//主机发送的第一个数据当作要写入RAM的地址
		BCLR		I2C_Flag,0
		MOVRR		I2CDATA,RAM_Add
		RETURN		

;******************************************************************************
;==============================从机接收地址无应答==============================
;******************************************************************************	
STATE_SRADRNACK: 
        BSET		I2CCR,2
		RETURN

;******************************************************************************
;==========================从机发送重复开始或停止信号=========================
;******************************************************************************			
STATE_SRSTART:     
        BSET		I2CCR,2
		RETURN	

;******************************************************************************
;==============================从机发送地址应答================================
;******************************************************************************	
STATE_SWADRACK		
		CLRR		FSR1H
		MOVRR		RAM_Add,FSR1L
		MOVRR		INDF1,I2CDATA
		INCR		RAM_Add,1
		INCR		Number,1
		BSET		I2CCR,2
		RETURN
	
;******************************************************************************
;==============================从机发送数据应答================================
;******************************************************************************		
STATE_SWDATACK:
		CLRR		FSR1H
		MOVRR		RAM_Add,FSR1L		
		MOVRR		INDF1,I2CDATA
		INCR		RAM_Add,1
		INCR		Number,1
		BSET		I2CCR,2
		RETURN

;******************************************************************************
;==============================从机发送数据无应答==============================
;******************************************************************************		
STATE_SWDATNACK:
		BSET		I2CCR,2
		RETURN

;******************************************************************************
;==============================从机发送最后数据应答============================
;******************************************************************************
STATE_SWLAST:
		BSET		I2CCR,2
		RETURN

;******************************************************************************
;=================================状态错误=====================================
;******************************************************************************						
STATE_Err:
		NOP
	    GOTO		STATE_Err
