/*******************(C) COPYRIGHT 2021 Masses-Chip ******************************
*Project Name        : M9F680_I2C_SLAVER.prj
* File Name          : M9F680_I2C_SLAVER_WORK.C
* Author             : MASSES CHIP
* Version            : V2.00
* Date               : 2021/10/08
* Web    			 : www.masses-chip.com
* FAE                : Luo
;					 : QQ：411680975
********************************************************************************
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例是作为I2C从机机(SCL:IOB0 SDA:IOB1)
;从机读：从机接收数据放入设定的RAM区中，从机接收的第一个数据为要写入RAM的地址
;其他数据依次写入RAM中
;从机写：主机会先发送一个数据当作要读出RAM区的地址，再依次把RAM区数据写给主机
******************************************************************************/
//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "zc.h"
#include "MASSESCHIP_DEFINE.H"

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#define		STA_S_RSTART		0xA0		//从机发送重复开始或停止信号
#define		STA_S_W_ADRACK		0xA8		//从机发送地址应答
#define		STA_S_W_DATACK		0xB8		//从机发送数据应答
#define		STA_S_W_DATNACK		0xC0		//从机发送数据无应答
#define		STA_S_W_LAST		0xC8		//从机发送最后数据应答
#define		STA_S_R_ADRACK		0x60		//从机接收地址应答
#define		STA_S_R_DATACK		0x80		//从机接收数据应答
#define		STA_S_R_ADRNACK		0x88		//从机接收地址无应答
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


uchar Number;
uchar I2C_Flag;
uchar RAM_Add;

void STATE_SRADRACK(void);					//从机接收地址应答
void STATE_SRDATACK(void);					//从机接收数据应答
void STATE_SWADRACK(void);					//从机发送地址应答
void STATE_SWDATACK(void);					//从机发送数据应答
void STATE_Err(void);						//状态错误
/*===============================================================================
**********************************I2C初始化***********************************
1、端口设置：设置IOB0、IOB1为上拉、数字口，设置端口复用功能IOB0---SCL,IOB1---SDA
2、I2C设置：作从机，从机地址0xA0
3、开中断
4、在RAM区写数据：在RAM区(0x0020-0x002F)写入0x0F-0x00
===============================================================================*/	
void I2C_INIT(void)
{
//1、端口设置
	PUB0 = 1;
	PUB1 = 1;
	ANSB = 0;
	MPSCL = 0x10;
	MPSDA = 0x11;
	
//2、I2C设置
	I2CCR = 0x44;	
	I2CADR = 0xA0;

//3、开中断
	I2C0IE = 1;
	GIEH = 1;
	
//4、在RAM区写数据	
	FSR0H = 0;
	FSR0L = 0x20;
	Number = 0x0F;
	for(;Number != 0;)
	{
		POSTINC0 = Number;
		Number--;
	}
}

/*===============================================================================
**********************************I2C从机中断处理********************************
从机读：从机接收数据放入设定的RAM区中，从机接收的第一个数据为要写入RAM的地址
其他数据依次写入RAM中
从机写：主机会先发送一个数据当作要读出RAM区的地址，再依次把RAM区数据写给主机
===============================================================================*/
void I2C_Slaver_Work(void)
{
	switch(I2CSTA)
	{
		case STA_S_R_ADRACK:				//从机接收地址应答
		{
			STATE_SRADRACK();
			break;
		}
		case STA_S_R_DATACK:				//从机接收数据应答
		{
			STATE_SRDATACK();
			break;
		}
		case STA_S_R_ADRNACK:				//从机接收地址无应答
		{
			ACK = 1;	
			break;
		}
		case STA_S_RSTART:					//从机发送重复开始或停止信号
		{
			ACK = 1;
			break;
		}
		case STA_S_W_ADRACK:				//从机发送地址应答
		{
			STATE_SWADRACK();
			break;
		}
		case STA_S_W_DATACK:				//从机发送数据应答
		{
			STATE_SWDATACK();
			break;
		}
		case STA_S_W_DATNACK:				//从机发送数据无应答
		{
			ACK = 1;
			break;
		}
		case STA_S_W_LAST:					//从机发送最后数据应答
		{
			ACK = 1;
			break;
		}
		default:							//状态错误
		{
			STATE_Err();
		}
	}
}
	
/******************************************************************************
===============================从机接收地址应答================================
******************************************************************************/	
void STATE_SRADRACK(void)
{
	ACK = 1;
	I2C_Flag = 1;
	Number = 0x20;
}
	
/******************************************************************************
==============================从机接收数据应答================================
******************************************************************************/	
void STATE_SRDATACK(void)
{
	if(I2C_Flag != 1)
	{
		if(--Number != 0)
		{
			FSR1H = 0;
			FSR1L = RAM_Add;
			INDF1 = I2CDATA;				//数据放入RAM中
			RAM_Add++;
			ACK = 1;
		}
		else
		{
			ACK = 0;
		}
	}
	else									//主机发送的第一个数据当作要写入RAM的地址
	{
		I2C_Flag = 0;						
		RAM_Add = I2CDATA;
	}
}

/******************************************************************************
==============================从机发送地址应答================================
******************************************************************************/	
void STATE_SWADRACK(void)
{
	FSR1H = 0;
	FSR1L = RAM_Add;
	I2CDATA = INDF1;
	RAM_Add++;
	Number++;
	ACK = 1;
}
	
/******************************************************************************
==============================从机发送数据应答================================
******************************************************************************/		
void STATE_SWDATACK(void)
{
	FSR1H = 0;
	FSR1L = RAM_Add;
	I2CDATA = INDF1;
	RAM_Add++;
	Number++;
	ACK = 1;
}
	
/******************************************************************************
=================================状态错误=====================================
******************************************************************************/						
void STATE_Err(void)
{
	while(1);
}
	