;*******************(ASM) COPYRIGHT 2021 Masses-Chip ****************************
;* Project Name		  : M9F680_IO_Interrupt.Prj
;* File Name		  : M9F680_IO_Interrupt.ASM
;* Author			  : MASSES CHIP
;* Version			  : V2.00
;* Date				  : 2021/09/15
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;
;Option:16M/16T,WDT-Disable-288ms,RST-IO,BOR 2.4V 
;说明：本范例为若产生IOB0中断，唤醒休眠，翻转IOB1
;//******************************************************************************
;//===============================================================================
;//***********************************头文件**************************************
;//用户不可更改
;//===============================================================================
		LIST		p=M9F680
INCLUDE		M9F680.INC

;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
USERDATA  udata 	H'00'
Flag		res    1	
#define	b_IO_Interrupt_Flag		Flag,0
;//===============================================================================
;//*********************************C O D E***************************************
;//===============================================================================	
		ORG			0000H
		GOTO		MainProgram
		ORG			0008H
		GOTO		Interrupt	

;//===============================================================================
;//********************************程序主函数*************************************
;//===============================================================================			
;//------------------------------程序初始化---------------------------------------
MainProgram:
		CALL       	SYSTEM_INIT				;//系统初始化
		CALL       	Clr_RAM_0000H_01FFH		;//清零RAM
		CALL       	IOB_Interrupt_INIT		;//IOB中断初始化
;//------------------------------主函数循环---------------------------------------		
MainLoop:
		JBTS1		b_IO_Interrupt_Flag
		GOTO		MainLoop_1
		BCLR		b_IO_Interrupt_Flag
		BNEG		IOB,1
MainLoop_1:		
		BSET		OSCM,STOP
		GOTO		MainLoop

			
;//===============================================================================
;//******************************中断服务子程序***********************************
;//===============================================================================
;//中断进来	
Interrupt:
		JBTS1		INTF1,1
		GOTO		Interrupt_END
		BCLR		INTF1,1
		bset		b_IO_Interrupt_Flag

Interrupt_END:	
;//中断结束
	    RETIE		1						;//返回A、BSR、STATUS的值

;//===============================================================================
;//*********************************IOB中断初始化*************************************
;//IOB0设置为输入下拉，开启IOB0变化中断
;//开启芯片休眠模式
;//===============================================================================	
IOB_Interrupt_INIT:
;//开启IOB中断	
		MOVIA		0xFE
		MOVAR		OEB
		MOVIA		0x01
		MOVAR		PDB
		MOVIA		0x01
		MOVAR		IOBICR
		BCLR		INTF1,1
		BSET		INTCR1,1
		BSET		OPTION,7	
;//进休眠 
		MOVIA		0x05
		MOVAR		OSCM		   	   					
		RETURN
		
		

;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置个IO状态为输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================		
SYSTEM_INIT:
;//-----------------------------------------------------------------------           
;//Init Clock		
		MOVIA       b'00000000'
		MOVAR		OSCM
;//Init IO 
		BANKBSR	   	0x0F		;//切页，ANSX寄存器需要切页操作
        ;//IOA
        MOVIA      	0x00 
		MOVAR		ANSA		;//0:数字口	  1:模拟口 
        MOVAR     	PUA			;//0:上拉关闭 1:上拉使能  	 	
        MOVAR      	PDA			;//0:下拉关闭 1:下拉使能
		MOVAR      	IOA        	;//0:输出低   1:输出高
		MOVIA      	0xFF    	
        MOVAR      	OEA			;//0:输入     1:输出   	
		;//IOB
        MOVIA      	0x00
		MOVAR		ANSB		    	
        MOVAR      	PUB 	
        MOVAR      	PDB  	
        MOVAR      	IOB
		MOVIA      	0xFF    	
        MOVAR      	OEB
		;//IOC
        MOVIA      	0x00
		MOVAR		ANSC
        MOVAR      	PUC  	
        MOVAR      	PDC   	
        MOVAR      	IOC
		MOVIA      	0xFF    	
        MOVAR      	OEC		
		;//IOD
        MOVIA      	0x00 
		MOVAR		ANSD
        MOVAR      	PUD    	
        MOVAR      	PDD   	
        MOVAR      	IOD 
		MOVIA      	0xFF    	
        MOVAR      	OED			  
;//------------------------------------------------------------------------      
;//Init Interrupt          
        BCLR       	OPTION,6  		;//1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
		BCLR       	OPTION,7		;//1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
		RETURN
		
;//===============================================================================
;//*****************************RAM清零(0000H~01FFH)******************************
;//RAM清零：RAM区0000H~01FFH全部清零；
;//===============================================================================				
Clr_RAM_0000H_01FFH:		
		CLRR    	FSR1L    
		CLRR    	FSR1H
ClrRam_Loop:
		MOVIA		0x00
		MOVAR   	INDF1
		INCR    	FSR1L,1
		MOVIA		0
		ADCAR		FSR1H,1
		MOVIA		2
		SUBRA		FSR1H,0
		JBTS1		STATUS,C
		GOTO    	ClrRam_Loop
RAM_INIT_END:
		RETURN				
		

		END
;//******************************END OF FILE*************************************
        











