/*******************(C) COPYRIGHT 2021 Masses-Chip ******************************
*Project Name        : M9F680_IO_Interrupt.Prj
* File Name          : M9F680_IO_Interrupt.C
* Author             : MASSES CHIP
* Version            : V2.00
* Date               : 2021/09/15
* Web    			 : www.masses-chip.com
* FAE                : Luo
*  				 	 : QQ：411680975
********************************************************************************
*
*Option:16M/16T,WDT-Disable-288ms,RST-IO,BOR 2.4V 
*说明：本范例为若产生IOB0中断，则唤醒休眠，翻转IOB1
******************************************************************************/
//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "zc.h"
#include "MASSESCHIP_DEFINE.H"

//===============================================================================
//******************************定义全局变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
ab8	Flag;
#define	b_IO_Interrupt_Flag	Flag.oneBit.b0
//-------------------------------------------------------------------------------
//用户可以自行更改
void SYSTEM_INIT(void);					//系统初始化
void IOB_Interrupt_INIT(void);			//IOB中断初始化
 

//===============================================================================
//********************************程序主函数*************************************
//===============================================================================
void main(void)					  		//程序主函数
{
  SYSTEM_INIT();                  		//系统初始化
  IOB_Interrupt_INIT();				   	//IOB中断初始化
  while(1) 
  {
	if(b_IO_Interrupt_Flag==1)
	{
		b_IO_Interrupt_Flag = 0;
		if(IOB1==1)
			IOB1 = 0;
		else
			IOB1 = 1;
	}
	STOP = 1;
  }
}
//===============================================================================
//******************************中断服务子程序***********************************
//高优先级中断入口需调用空函数做断点保护
//注：中断处理调用子函数处理，不要再这里直接处理
//===============================================================================
void interrupt high_priority Intr(void)		
{
	#asm
		call  _breakpoint_protect,f			
	#endasm							
	if(IOBCHIF)
	{
		IOBCHIF = 0;
		b_IO_Interrupt_Flag = 1;
	}
}
//===============================================================================
//**********************************空函数***************************************
//空函数做断点保护
//用户不可更改
//===============================================================================
void breakpoint_protect()
{
	
}


//===============================================================================
//*********************************IOB中断初始化*************************************
//IOB0设置为输入下拉，开启IOB0变化中断
//开启芯片休眠模式
//===============================================================================
void IOB_Interrupt_INIT(void)
{
//1、开启IOB中断
	OEB = 0xFE;
	PDB = 0x01;
	IOBICR = 0x01;
	IOBCHIE = 1;	
	IOBCHIF = 0;
	GIEH = 1;
//2、进休眠
	OSCM = 0x05;

}

//===============================================================================
//**********************************系统初始化***********************************
//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
//IO初始化:设置个IO状态为输出低，且关闭上下拉
//中断总开关：关闭总开关
//===============================================================================	
void SYSTEM_INIT(void)
{ 
//----------------------------------------------------
//Init 系统时钟
	OSCM = 0x00;
//----------------------------------------------------	            
//Init IO
	//IOA
	ANSA = 0x00;               //0:数字口	1:模拟口 
	PUA = 0x00;                //0:上拉关闭 1:上拉使能
	PDA = 0x00;				   //0:下拉关闭 1:下拉使能
	IOA = 0x00;                //IO口数据
	OEA = 0xFF;                //0:输入 1:输出
	//IOB
	ANSB = 0x00;  
	PUB = 0x00;                
	PDB = 0x00;				   
	IOB = 0x00;                
	OEB = 0xFF;                
	//IOC
	ANSC = 0x00;  
	PUC = 0x00;               
	PDC = 0x00;				   
	IOC = 0x00;                
	OEC = 0xFF;              
	//IOD
	ANSD = 0x00;  
	PUD = 0x00;               
	PDD = 0x00;				   
	IOD = 0x00;               
	OED = 0xFF;                
             
//----------------------------------------------------     
//Init Interrupt
	GIEH = 0;                  //1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
	GIEL = 0;                  //1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
}


/*********************************END OF FILE************************************/
