;*******************(ASM) COPYRIGHT 2021 Masses-Chip ****************************
;* Project Name		  : M9F680_PWM1.Prj
;* File Name		  : M9F680_PWM1.ASM
;* Author			  : MASSES CHIP
;* Version			  : V2.00
;* Date				  : 2021/09/15
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例使用PWM1输出1KHz占空比为50%的方波,前后死区均为15us
;方波循环开启100ms,关闭100ms
;PWM10复用口为B0
;PWM11复用口为B1
;//******************************************************************************
;//===============================================================================
;//***********************************头文件**************************************
;//用户不可更改
;//===============================================================================
		LIST		p=M9F680
INCLUDE		M9F680.INC

;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
USERDATA  udata 	H'00'
Delay_Count			res    1	
Delay_Count_1		res    1
;//===============================================================================
;//*********************************C O D E***************************************
;//===============================================================================	
		ORG			0000H
		GOTO		MainProgram
		ORG			0008H
		GOTO		Interrupt	

;//===============================================================================
;//********************************程序主函数*************************************
;//===============================================================================			
;//------------------------------程序初始化---------------------------------------
MainProgram:
		CALL       	SYSTEM_INIT				;//系统初始化
		CALL       	Clr_RAM_0000H_01FFH		;//清零RAM
		CALL       	PWM1_INIT				;//PWM1初始化
;//------------------------------主函数循环---------------------------------------		
MainLoop:
		CLRWDT
		BSET		PWM1CR,6
		BSET		PWM1CR,3
		CALL		Delay_100ms
		BCLR		PWM1CR,6
		BCLR		PWM1CR,3
		CALL		Delay_100ms
		GOTO		MainLoop

;//===============================================================================
;//******************************延时处理程序*************************************
;//===============================================================================
Delay_100ms:
		MOVIA		250
		MOVAR		Delay_Count
		MOVIA		130
		MOVAR		Delay_Count_1
Delay_100ms_1:		
		DJZR		Delay_Count_1,1
		GOTO		Delay_100ms_2
		RETURN
Delay_100ms_2:
		DJZR		Delay_Count,1
		GOTO		$-1
		GOTO		Delay_100ms_1
		
		
;//===============================================================================
;//******************************中断服务子程序***********************************
;//===============================================================================
;//中断进来	
Interrupt:
		;//
		;//中断处理程序
		;//
Interrupt_END:	
;//中断结束
	    RETIE		1						;//返回A、BSR、STATUS的值

;//===============================================================================
;//*********************************PWM1初始化*************************************
;//TC1设置：16位模式，16M，高频系统时钟，1:16分频
;//PWM1配置，互补输出，前后死区均为15us
;//===============================================================================	
PWM1_INIT:
;//1、PWM1输出端口设置
;//PWM10复用口为B0
;//PWM11复用口为B1
		BANKBSR		0x0F
		MOVIA		0x10
		MOVAR		MPPWM10
		MOVIA		0x11
		MOVAR		MPPWM11

;//2、TC1设置
		MOVIA		0x0C
		MOVAR		T1CR
		CLRR		TC1CL
		CLRR 		TC1CH
		MOVIA		0xE7
		MOVAR		TC1PRL
		MOVIA 		0x03
		MOVAR		TC1PRH
		BSET 		T1CR,7
		
;//3、PWM1设置
		MOVIA		0x93
		MOVAR		PWM1CR	
		MOVIA		0x01
		MOVAR		PWM10DH
		MOVIA		0xF3
		MOVAR		PWM10DL	
		
;//4、死区设置	
		MOVIA		0x0F
		MOVAR		PWM11DH
		MOVAR		PWM11DL							   	   					
		RETURN
		
		

;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置个IO状态为输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================		
SYSTEM_INIT:
;//-----------------------------------------------------------------------           
;//Init Clock		
		MOVIA       b'00000000'
		MOVAR		OSCM
;//Init IO 
		BANKBSR	   	0x0F		;//切页，ANSX寄存器需要切页操作
        ;//IOA
        MOVIA      	0x00 
		MOVAR		ANSA		;//0:数字口	  1:模拟口 
        MOVAR     	PUA			;//0:上拉关闭 1:上拉使能  	 	
        MOVAR      	PDA			;//0:下拉关闭 1:下拉使能
		MOVAR      	IOA        	;//0:输出低   1:输出高
		MOVIA      	0xFF    	
        MOVAR      	OEA			;//0:输入     1:输出   	
		;//IOB
        MOVIA      	0x00
		MOVAR		ANSB		    	
        MOVAR      	PUB 	
        MOVAR      	PDB  	
        MOVAR      	IOB
		MOVIA      	0xFF    	
        MOVAR      	OEB
		;//IOC
        MOVIA      	0x00
		MOVAR		ANSC
        MOVAR      	PUC  	
        MOVAR      	PDC   	
        MOVAR      	IOC
		MOVIA      	0xFF    	
        MOVAR      	OEC		
		;//IOD
        MOVIA      	0x00 
		MOVAR		ANSD
        MOVAR      	PUD    	
        MOVAR      	PDD   	
        MOVAR      	IOD 
		MOVIA      	0xFF    	
        MOVAR      	OED			  
;//------------------------------------------------------------------------      
;//Init Interrupt          
        BCLR       	OPTION,6  		;//1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
		BCLR       	OPTION,7		;//1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
		RETURN
		
;//===============================================================================
;//*****************************RAM清零(0000H~01FFH)******************************
;//RAM清零：RAM区0000H~01FFH全部清零；
;//===============================================================================				
Clr_RAM_0000H_01FFH:		
		CLRR    	FSR1L    
		CLRR    	FSR1H
ClrRam_Loop:
		MOVIA		0x00
		MOVAR   	INDF1
		INCR    	FSR1L,1
		MOVIA		0
		ADCAR		FSR1H,1
		MOVIA		2
		SUBRA		FSR1H,0
		JBTS1		STATUS,C
		GOTO    	ClrRam_Loop
RAM_INIT_END:
		RETURN				
		

		END
;//******************************END OF FILE*************************************
        











