/*******************(C) COPYRIGHT 2021 Masses-Chip ******************************
*Project Name        : M9F680_PWM1.Prj
* File Name          : M9F680_PWM1.C
* Author             : MASSES CHIP
* Version            : V2.00
* Date               : 2021/09/15
;* Web    			 : www.masses-chip.com
;* FAE               : Luo
;  				 	 : QQ：411680975
********************************************************************************
*
*Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
*说明：本范例使用PWM1输出1KHz占空比为50%的方波,前后死区均为15us
*方波循环开启100ms,关闭100ms
*PWM10复用口为B0
*PWM11复用口为B1
******************************************************************************/
//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "zc.h"
#include "MASSESCHIP_DEFINE.H"

//===============================================================================
//******************************定义全局变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
uchar 	Delay_Count;
uchar	Delay_Count_1;
//用户可以自行更改
void SYSTEM_INIT(void);					//系统初始化
void PWM1_INIT(void);					//PWM1初始化
void Delay_100ms(void);					//延时100ms

//===============================================================================
//********************************程序主函数*************************************
//===============================================================================
void main(void)					  		//程序主函数
{
  SYSTEM_INIT();                  		//系统初始化
  PWM1_INIT();				   	  		//PWM1初始化
  while(1) 
  {
    CLRWDT();					  		//清除看门狗
	PWM10OE = 1;
	PWM11OE = 1;
	Delay_100ms();
	PWM10OE = 0;
	PWM11OE = 0;		
	Delay_100ms();	
  }
}
//===============================================================================
//******************************中断服务子程序***********************************
//高优先级中断入口需调用空函数做断点保护
//注：中断处理调用子函数处理，不要再这里直接处理
//===============================================================================
void interrupt high_priority Intr(void)		
{
	#asm
		call  _breakpoint_protect,f		//空函数做断点保护，用户不可更改	
	#endasm							
	/*
		中断处理子函数的调用
	*/
}
//===============================================================================
//**********************************空函数***************************************
//空函数做断点保护
//用户不可更改
//===============================================================================
void breakpoint_protect()
{
	
}

//===============================================================================
//*********************************延时100ms************************************
//延时100ms
//===============================================================================
void Delay_100ms(void)
{
	for(Delay_Count_1=100;Delay_Count_1>0;Delay_Count_1--)
	{
		for(Delay_Count=250;Delay_Count>0;Delay_Count--);
	}
}

//===============================================================================
//*********************************PWM1初始化************************************
//TC1设置：16位模式，16M，高频系统时钟，1:16分频
//PWM1配置，互补输出，前后死区均为15us
//===============================================================================
void PWM1_INIT(void)
{
//1、PWM1输出口设置
//PWM10复用口为B0
//PWM10复用口为B1
	MPPWM10 = 0x10;
	MPPWM11 = 0x11;
	
//2、TC1设置	
	T1CR = 0x0C;
	TC1CL = 0;
	TC1CH = 0;
	TC1PRL = 0xE7;
	TC1PRH = 0x03;
	TC1EN = 1;
	
//3、PWM1设置 
	PWM1CR = 0x93;	
	PWM10DH = 0X01;
	PWM10DL = 0xF3;
	
//4、死区设置
	PWM11DH = 0x0F;
	PWM11DL = 0x0F;
}

//===============================================================================
//**********************************系统初始化***********************************
//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
//IO初始化:设置个IO状态为输出低，且关闭上下拉
//中断总开关：关闭总开关
//===============================================================================	
void SYSTEM_INIT(void)
{ 
//----------------------------------------------------
//Init 系统时钟
	OSCM = 0x00;
//----------------------------------------------------	            
//Init IO
	//IOA
	ANSA = 0x00;               //0:数字口	1:模拟口 
	PUA = 0x00;                //0:上拉关闭 1:上拉使能
	PDA = 0x00;				   //0:下拉关闭 1:下拉使能
	IOA = 0x00;                //IO口数据
	OEA = 0xFF;                //0:输入 1:输出
	//IOB
	ANSB = 0x00;  
	PUB = 0x00;                
	PDB = 0x00;				   
	IOB = 0x00;                
	OEB = 0xFF;                
	//IOC
	ANSC = 0x00;  
	PUC = 0x00;               
	PDC = 0x00;				   
	IOC = 0x00;                
	OEC = 0xFF;              
	//IOD
	ANSD = 0x00;  
	PUD = 0x00;               
	PDD = 0x00;				   
	IOD = 0x00;               
	OED = 0xFF;                
             
//----------------------------------------------------     
//Init Interrupt
	GIEH = 0;                  //1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
	GIEL = 0;                  //1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
}

/*********************************END OF FILE************************************/
