;*******************(ASM) COPYRIGHT 2021 Masses-Chip ****************************
;* Project Name		  : M9F680_TC0.Prj
;* File Name		  : M9F680_TC0.ASM
;* Author			  : MASSES CHIP
;* Version			  : V2.00
;* Date				  : 2021/09/15
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例用TC0做定时器，每1ms翻转一次IOB1口
;//******************************************************************************
;//===============================================================================
;//***********************************头文件**************************************
;//用户不可更改
;//===============================================================================
		LIST		p=M9F680
INCLUDE		M9F680.INC

;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
userdata udata	H'00'
Flag		res    1
#define		b_TC0_Flag		Flag,0

;//===============================================================================
;//*********************************C O D E***************************************
;//===============================================================================	
		ORG			0000H
		GOTO		MainProgram
		ORG			0008H
		GOTO		Interrupt	

;//===============================================================================
;//********************************程序主函数*************************************
;//主循环每1ms翻转一次IOB1		
;//------------------------------程序初始化---------------------------------------
MainProgram:
		CALL       	SYSTEM_INIT				;//系统初始化
		CALL       	Clr_RAM_0000H_01FFH		;//清零RAM
		CALL       	TC0_INIT				;//TC0初始化
;//------------------------------主函数循环---------------------------------------		
MainLoop:
		CLRWDT	
		JBTS1		b_TC0_Flag
		GOTO	    MainLoop
		BCLR		b_TC0_Flag
		BNEG		IOB,1
		GOTO		MainLoop
		
		
;//===============================================================================
;//******************************中断服务子程序***********************************
;//定时器TC0每计数1ms，进一次中断，标志位置高 
;//===============================================================================
;//中断进来	
Interrupt:
		JBTS1		INTF0,TC0IF					
		GOTO		Interrupt_END	
		BCLR		INTF0,TC0IF	
		BSET		b_TC0_Flag
Interrupt_END:	
;//中断结束
	    RETIE		1						;//返回A、BSR、STATUS的值

;//===============================================================================
;//*********************************TC0初始化*************************************
;//TC0设置：8位模式，16M，高频系统时钟，1:64分频
;//t =计数/（时钟/分频）     1ms = （249+1）/（16/64）
;//开启TC0溢出中断和总中断
;//===============================================================================	
TC0_INIT:
;//1、TC0设置
		MOVIA      	0x2E
		MOVAR	    T0CR		               		
		CLRR	   	TC0CH                    			
		MOVIA      	249
		MOVAR	   	TC0CL
		BSET       	T0CR,7	
;//2、中断设置
		BCLR		INTF0,TC0IF							
		BSET		INTCR0,TC0IE									   	   			
		BSET       	OPTION,7				   	   					
		RETURN
		
		

;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置个IO状态为输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================		
SYSTEM_INIT:
;//-----------------------------------------------------------------------           
;//Init Clock		
		MOVIA       b'00000000'
		MOVAR		OSCM
;//Init IO 
		BANKBSR	   	0x0F		;//切页，ANSX寄存器需要切页操作
        ;//IOA
        MOVIA      	0x00 
		MOVAR		ANSA		;//0:数字口	  1:模拟口 
        MOVAR     	PUA			;//0:上拉关闭 1:上拉使能  	 	
        MOVAR      	PDA			;//0:下拉关闭 1:下拉使能
		MOVAR      	IOA        	;//0:输出低   1:输出高
		MOVIA      	0xFF    	
        MOVAR      	OEA			;//0:输入     1:输出   	
		;//IOB
        MOVIA      	0x00
		MOVAR		ANSB		    	
        MOVAR      	PUB 	
        MOVAR      	PDB  	
        MOVAR      	IOB
		MOVIA      	0xFF    	
        MOVAR      	OEB
		;//IOC
        MOVIA      	0x00
		MOVAR		ANSC
        MOVAR      	PUC  	
        MOVAR      	PDC   	
        MOVAR      	IOC
		MOVIA      	0xFF    	
        MOVAR      	OEC		
		;//IOD
        MOVIA      	0x00 
		MOVAR		ANSD
        MOVAR      	PUD    	
        MOVAR      	PDD   	
        MOVAR      	IOD 
		MOVIA      	0xFF    	
        MOVAR      	OED			  
;//------------------------------------------------------------------------      
;//Init Interrupt          
        BCLR       	OPTION,6  		;//1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
		BCLR       	OPTION,7		;//1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
		RETURN
		
;//===============================================================================
;//*****************************RAM清零(0000H~01FFH)******************************
;//RAM清零：RAM区0000H~01FFH全部清零；
;//===============================================================================				
Clr_RAM_0000H_01FFH:		
		CLRR    	FSR1L    
		CLRR    	FSR1H
ClrRam_Loop:
		MOVIA		0x00
		MOVAR   	INDF1
		INCR    	FSR1L,1
		MOVIA		0
		ADCAR		FSR1H,1
		MOVIA		2
		SUBRA		FSR1H,0
		JBTS1		STATUS,C
		GOTO    	ClrRam_Loop
RAM_INIT_END:
		RETURN				
		

		END
;//******************************END OF FILE*************************************
        











