;*******************(ASM) COPYRIGHT 2021 Masses-Chip ****************************
;* Project Name		  : M9F680_Usart.Prj
;* File Name		  : M9F680_Usart.ASM
;* Author			  : MASSES CHIP
;* Version			  : V2.00
;* Date				  : 2021/09/15
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例为异步串口通讯，串口每100ms发送一个字节数据，串口波特率为38400
;串口接收数据放在Receive_Data寄存器中
;串口接收错误数据放在Receive_Data_Err寄存器中
;TX和RX可以复用，本范例TX端口选择IOB0，RX端口选择IOB1
;//******************************************************************************
;//===============================================================================
;//***********************************头文件**************************************
;//用户不可更改
;//===============================================================================
		LIST		p=M9F680
INCLUDE		M9F680.INC

;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
USERDATA udata	H'00'
Receive_Data		res    1	
Receive_Data_Err	res	   1
Delay_Count			res	   1
Delay_Count_1		res	   1
;//===============================================================================
;//*********************************C O D E***************************************
;//===============================================================================	
		ORG			0000H
		GOTO		MainProgram
		ORG			0008H
		GOTO		Interrupt	

;//===============================================================================
;//********************************程序主函数*************************************
;//===============================================================================			
;//------------------------------程序初始化---------------------------------------
MainProgram:
		CALL       	SYSTEM_INIT				;//系统初始化
		CALL       	Clr_RAM_0000H_01FFH		;//清零RAM
		CALL       	Usart_INIT				;//Usart初始化
;//------------------------------主函数循环---------------------------------------		
MainLoop:
		CLRWDT
		CALL		Delay_100ms
		CALL		Usaart_Send_Byte
		GOTO		MainLoop
		
		
;//===============================================================================
;//******************************中断服务子程序***********************************
;//Usart接收数据，存放在Receive_Data中
;//串口接收错误数据放在Receive_Data_Err寄存器中
;//===============================================================================
;//中断进来	
Interrupt:
		JBTS1		INTF0,7					
		GOTO		Interrupt_END	
		JBTS0		RX0CR,1
		GOTO		Receive_Err
		MOVR		RX0REG,0
		MOVAR		Receive_Data
		GOTO		Interrupt_END
		
Receive_Err:		
		MOVR		RX0REG,0
		MOVAR		Receive_Data_Err
		
Interrupt_END:	
;//中断结束
	    RETIE		1						;//返回A、BSR、STATUS的值


;//===============================================================================
;//******************************延时处理程序*************************************
;//===============================================================================
Delay_100ms:
		MOVIA		250
		MOVAR		Delay_Count
		MOVIA		130
		MOVAR		Delay_Count_1
Delay_100ms_1:		
		DJZR		Delay_Count_1,1
		GOTO		Delay_100ms_2
		RETURN
Delay_100ms_2:
		DJZR		Delay_Count,1
		GOTO		$-1
		GOTO		Delay_100ms_1

;//===============================================================================
;//******************************Usart发送子程序**********************************
;//Usart发送数据
;//发送一个字节数据
;//===============================================================================
Usaart_Send_Byte:
		MOVIA		0x12
		MOVAR		TX0REG
		JBTS1		TX0CR,6
		GOTO		$-1
		RETURN


;//===============================================================================
;//*********************************Usart初始化*************************************
;//Usart异步发送和接收设置
;//开启异步接收中断
;//===============================================================================	
Usart_INIT:
;//1、设置Usart复用口
;//TX复用口为IOB0
;//RX复用口为IOB1
		BANKBSR	   	0x0F
		MOVIA		0x10
		MOVAR		MPTX
		MOVIA		0x11
		MOVAR		MPRX
		MOVIA		0xFD
		MOVAR		OEB

;//2、Usart发送设置
		MOVIA		0x80
		MOVAR		TX0CR
		
;//3、波特率设置		
		MOVIA		0x67
		MOVAR		BRGD0L
		MOVIA		0x00
		MOVAR		BRGD0H

;//4、Usart接收设置
		MOVIA		0x80
		MOVAR		RX0CR
		
;//5、串口中断		
		BCLR		INTF0,7
		BCLR		INTCR0,6
		BSET		INTCR0,7
		BSET		OPTION,7
		;BSET		OPTION,6
		RETURN
		
		

;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置个IO状态为输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================		
SYSTEM_INIT:
;//-----------------------------------------------------------------------           
;//Init Clock		
		MOVIA       b'00000000'
		MOVAR		OSCM
;//Init IO 
		BANKBSR	   	0x0F		;//切页，ANSX寄存器需要切页操作
        ;//IOA
        MOVIA      	0x00 
		MOVAR		ANSA		;//0:数字口	  1:模拟口 
        MOVAR     	PUA			;//0:上拉关闭 1:上拉使能  	 	
        MOVAR      	PDA			;//0:下拉关闭 1:下拉使能
		MOVAR      	IOA        	;//0:输出低   1:输出高
		MOVIA      	0xFF    	
        MOVAR      	OEA			;//0:输入     1:输出   	
		;//IOB
        MOVIA      	0x00
		MOVAR		ANSB		    	
        MOVAR      	PUB 	
        MOVAR      	PDB  	
        MOVAR      	IOB
		MOVIA      	0xFF    	
        MOVAR      	OEB
		;//IOC
        MOVIA      	0x00
		MOVAR		ANSC
        MOVAR      	PUC  	
        MOVAR      	PDC   	
        MOVAR      	IOC
		MOVIA      	0xFF    	
        MOVAR      	OEC		
		;//IOD
        MOVIA      	0x00 
		MOVAR		ANSD
        MOVAR      	PUD    	
        MOVAR      	PDD   	
        MOVAR      	IOD 
		MOVIA      	0xFF    	
        MOVAR      	OED			  
;//------------------------------------------------------------------------      
;//Init Interrupt          
        BCLR       	OPTION,6  		;//1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
		BCLR       	OPTION,7		;//1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
		RETURN
		
;//===============================================================================
;//*****************************RAM清零(0000H~01FFH)******************************
;//RAM清零：RAM区0000H~01FFH全部清零；
;//===============================================================================				
Clr_RAM_0000H_01FFH:		
		CLRR    	FSR1L    
		CLRR    	FSR1H
ClrRam_Loop:
		MOVIA		0x00
		MOVAR   	INDF1
		INCR    	FSR1L,1
		MOVIA		0
		ADCAR		FSR1H,1
		MOVIA		2
		SUBRA		FSR1H,0
		JBTS1		STATUS,C
		GOTO    	ClrRam_Loop
RAM_INIT_END:
		RETURN				
		

		END
;//******************************END OF FILE*************************************
        











