/*******************(C) COPYRIGHT 2021 Masses-Chip ******************************
*Project Name        : M9F680_Usart.Prj
* File Name          : M9F680_Usart.C
* Author             : MASSES CHIP
* Version            : V2.00
* Date               : 2021/09/15
* Web    			 : www.masses-chip.com
* FAE                : Luo
*  				 	 : QQ：411680975
********************************************************************************
*
*Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
*说明：本范例为异步串口通讯，串口每100ms发送一个字节数据，串口波特率为38400
*中断接收数据放在Receive_Data寄存器中
*串口接收错误数据放在Receive_Data_Err寄存器中
*串口端口有复用功能，TX端口为IOB0，RX端口为IOB1
******************************************************************************/
//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "zc.h"
#include "MASSESCHIP_DEFINE.H"

//===============================================================================
//******************************定义全局变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
volatile unsigned char  Receive_Data;
volatile unsigned char  Receive_Data_Err;
volatile unsigned char 	Delay_Count;
volatile unsigned char 	Delay_Count_1;
//-------------------------------------------------------------------------------
//用户可以自行更改
void SYSTEM_INIT(void);						//系统初始化
void Usart_INIT(void);						//Usart初始化
void Usart_Send_Byte(unsigned char Data);	//发送一个字节数据	
void Receive_Interrupt (void);				//Usart_Receive中断处理函数
void Delay_100ms(void);						//延时100ms
//===============================================================================
//********************************程序主函数*************************************
//===============================================================================
void main(void)					  		//程序主函数
{
  SYSTEM_INIT();                  		//系统初始化
  Usart_INIT();				   	  		//Usart初始化
  while(1) 
  {
    CLRWDT();					  		//清除看门狗
	Delay_100ms();
	Usart_Send_Byte(0x12);
  }
}
//===============================================================================
//******************************中断服务子程序***********************************
//高优先级中断入口需调用空函数做断点保护
//注：中断处理调用子函数处理，不要再这里直接处理
//===============================================================================
void interrupt high_priority Intr(void)		
{
	#asm
		call  _breakpoint_protect,f			
	#endasm	
	Receive_Interrupt();							
	
}
//===============================================================================
//**********************************空函数***************************************
//空函数做断点保护
//用户不可更改
//===============================================================================
void breakpoint_protect()
{
	
}

//===============================================================================
//********************Usart_Receive中断处理函数**********************************
//Usart 接收数据存入Receive_Data寄存器中
//串口接收错误数据放在Receive_Data_Err寄存器中
//===============================================================================
void Receive_Interrupt (void)				
{
	if(RX0IF)
	{
		if(FRER==0)
			Receive_Data = RX0REG; 
		else 
			Receive_Data_Err = RX0REG;
	}
}


//===============================================================================
//**************************延时处理函数*****************************************
//延时100ms
//===============================================================================
void Delay_100ms(void)
{
	for(Delay_Count_1=100;Delay_Count_1>0;Delay_Count_1--)
	{
		for(Delay_Count=250;Delay_Count>0;Delay_Count--);
	}

}

//===============================================================================
//***************************Usart_Send处理函数**********************************
//发送一个8位数据
//===============================================================================
void Usart_Send_Byte(unsigned char Data)
{

	TX0REG = Data;
	while(TMCLR);

}



//===============================================================================
//*********************************Usart初始化***********************************
//Usart异步发送和接收设置
//开启异步接收中断,波特率为9600
//发送数据为8位，TX复用口为IOB0，RX复用口为IOB1
//===============================================================================
void Usart_INIT(void)
{
//1、设置Usart复用口
//TX复用口为IOB0
//RX复用口为IOB1
	MPTX = 0x10;
	MPRX = 0x11;
	OEB1 = 0;
//2、Usart发送设置
	TX0CR = 0x80;

//3、波特率设置
	BRGD0L = 0x67;
	BRGD0H = 0x00;

//4、Usart接收设置
	RX0CR = 0x80;

//5、中断设置
	RX0IF = 0;
	RX0IE = 1;
	GIEH = 1;
	GIEL = 1;				
}

//===============================================================================
//**********************************系统初始化***********************************
//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
//IO初始化:设置个IO状态为输出低，且关闭上下拉
//中断总开关：关闭总开关
//===============================================================================	
void SYSTEM_INIT(void)
{ 
//----------------------------------------------------
//Init 系统时钟
	OSCM = 0x00;
//----------------------------------------------------	            
//Init IO
	//IOA
	ANSA = 0x00;               //0:数字口	1:模拟口 
	PUA = 0x00;                //0:上拉关闭 1:上拉使能
	PDA = 0x00;				   //0:下拉关闭 1:下拉使能
	IOA = 0x00;                //IO口数据
	OEA = 0xFF;                //0:输入 1:输出
	//IOB
	ANSB = 0x00;  
	PUB = 0x00;                
	PDB = 0x00;				   
	IOB = 0x00;                
	OEB = 0xFF;                
	//IOC
	ANSC = 0x00;  
	PUC = 0x00;               
	PDC = 0x00;				   
	IOC = 0x00;                
	OEC = 0xFF;              
	//IOD
	ANSD = 0x00;  
	PUD = 0x00;               
	PDD = 0x00;				   
	IOD = 0x00;               
	OED = 0xFF;                
             
//----------------------------------------------------     
//Init Interrupt
	GIEH = 0;                  //1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
	GIEL = 0;                  //1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
}


/*********************************END OF FILE************************************/
